aboutsummaryrefslogtreecommitdiff
path: root/gcc/toplev.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/toplev.c')
-rw-r--r--gcc/toplev.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/gcc/toplev.c b/gcc/toplev.c
index 366dfdf..9121c21 100644
--- a/gcc/toplev.c
+++ b/gcc/toplev.c
@@ -346,8 +346,8 @@ int use_gnu_debug_info_extensions = 0;
int optimize = 0;
/* Nonzero means optimize for size. -Os.
- The only valid values are zero and non-zero. When optimize_size is
- non-zero, optimize defaults to 2, but certain individual code
+ The only valid values are zero and nonzero. When optimize_size is
+ nonzero, optimize defaults to 2, but certain individual code
bloating optimizations are disabled. */
int optimize_size = 0;
@@ -1893,7 +1893,7 @@ close_dump_file (index, func, insns)
/* Do any final processing required for the declarations in VEC, of
which there are LEN. We write out inline functions and variables
that have been deferred until this point, but which are required.
- Returns non-zero if anything was put out. */
+ Returns nonzero if anything was put out. */
int
wrapup_global_declarations (vec, len)
@@ -4732,7 +4732,7 @@ general_init (argv0)
minimal options processing. Outputting diagnostics is OK, but GC
and identifier hashtables etc. are not initialized yet.
- Return non-zero to suppress compiler back end initialization. */
+ Return nonzero to suppress compiler back end initialization. */
static void
parse_options_and_default_flags (argc, argv)
int argc;
@@ -5180,7 +5180,7 @@ backend_init ()
expand_dummy_function_end ();
}
/* Language-dependent initialization. Returns non-zero on success. */
static int
lang_dependent_init (name)
const char *name;
@@ -5180,7 +5180,7 @@ backend_init ()
expand_dummy_function_end ();
}
-/* Language-dependent initialization. Returns non-zero on success. */
+/* Language-dependent initialization. Returns nonzero on success. */
static int
lang_dependent_init (name)